#!/usr/bin/env python

import sys
import string
import math
import getopt

N = 32
L = 12.4138
(optlist, args) = getopt.getopt(sys.argv[1:],"N:V:",["N=", "L="])

for o, a in optlist:
    if o in ("-N", "--N"):
        N = int(a)
    if o in ("-L", "--L"):
        L = float(a)

# Read in values.
tab_input = [ [float(c) for c in string.strip(l).split() ] for l in sys.stdin.readlines() ]


n = len(tab_input)

def integrate_tabular(f, i1, i2, N, L):
    "Approximate definite integral of the tabulated function f*pi*r^2*rho from a=f(i1) to b=f(i2) using the Composite Simpson's rule. Interval must remain constant!"
    h = f[1][0] - f[0][0]
    V = L**3   # Volume
    # Add endpoints
    S = N/V*4*math.pi*(f[i1][1]*f[i1][0]**2 + f[i2][1]*f[i2][0]**2)
    # Add in one half
    S = S + N/V*4.0*4*math.pi*sum(f[k][1]*(f[k][0]**2) for k in range(i1+1, i2, 2))
    # And the other half
    S = S + N/V*2.0*4*math.pi*sum(f[k][1]*(f[k][0]**2) for k in range(i1+2, i2, 2))
    return (f[i2][0], S/3.0*h)


nc = [ ]

# Calculate indefinite integral
for i in range(n):
    nc = nc + [integrate_tabular(tab_input, 0, i, N, L), ]

# Tabulate the result
for i in range(n):
    print tab_input[i][0], nc[i][1]



