#!/bin/bash

rm -f fe_profile pmf_profile  lambda_profile


dists="2.5 2.6 2.7 2.8 2.9 3.0 3.1 3.2 3.3 3.4 3.5 3.6 3.7 3.8 3.9 4.0 4.1 4.2 4.3 4.4 4.5 4.6 4.7 4.8 4.9 5.0 5.1 5.2 5.3 5.4 5.5 5.6 5.7 5.8 5.9 6.0"

for dist in  $dists
do
  echo "Computing average of Shake Lagrange multiplier for distance $dist"
  lambda=`cat NACL-CONSTRAINED-${dist}-1.LagrangeMultLog | awk '{c++ ; if (c>10 && $1=="Shake") print $NF}' | awk '{c++ ; s=s+$1}END{print s/c}'`
  echo $dist $lambda >> lambda_profile
done

# 
# now do the thermodynamic integration
#
# dx: is the spacing in A
# s : an arbitrary shift (we have only a free energy difference between points)
# 0.529177 : the conversion from bohr to angstrom.... the Lagrange multiplier is in atomic units (Hartree/bohr)
#
echo "Integrating Free Energy Profile..."
awk 'BEGIN{dx=0.1; s=0.0}{print $1-dx/2,s ; s=s-$2*dx/0.529177}' lambda_profile > fe_profile

# 
# Subtract entropic force in order to obtain the Potential of Mean force
#
# dx: is the spacing in A
# s : an arbitrary shift (we have only a free energy difference between points)
# 0.529177 : the conversion from bohr to angstrom.... the Lagrange multiplier is in atomic units (Hartree/bohr)
# 3.16678e-6: kB*1K in units of Hartree
#
echo "Integrating Potential of Mean Force..."
awk 'BEGIN{dx=0.1; s=0.0; T=350; tmp=0}{print $1-dx/2,s ; tmp = $2 - 3.16678e-6*T/$1*0.529177; s=s-tmp*dx/0.529177  }' lambda_profile > pmf_profile
